#!/usr/bin/env python
import argparse
import subprocess
import sys

def call_process(*args, **kwargs):
    _result = subprocess.check_output(*args, **kwargs)
    return _result.decode("utf-8") if sys.version_info.major > 2 else _result

def parse_args():
    parser = argparse.ArgumentParser()
    parser.add_argument("--git-dir", default="/srv/salt/reclass")
    parser.add_argument("--remote", default="origin")
    parser.add_argument("--branch", default="master")
    return parser.parse_args()

CHANGES_FORMAT = '''reclass_staged_changes,directory={dir} value={staged}
reclass_unstaged_changes,directory={dir} value={unstaged}'''

if __name__ == "__main__":
    args = parse_args()
    git_dir = args.git_dir.strip()

    staged, unstaged = [], []
    for file_status in call_process(
        str.split('git status --porcelain'), cwd=git_dir
    ).splitlines():
        if file_status[0] not in (' ', '?'):
            staged.append(file_status[3:].strip())
        if file_status[1] != ' ':
            unstaged.append(file_status[3:].strip())

    print(CHANGES_FORMAT.format(
        dir=git_dir, staged=len(staged), unstaged=len(unstaged)
    ))

    if args.remote.strip() in call_process(
        str.split('git remote show'), cwd=git_dir
    ).splitlines():
        # 0 if local branch is synced with remote, 1 otherwise
        print('reclass_remote_desync,directory={dir} value={val}'.format(
            dir=git_dir, val=int(bool(call_process(
                str.split("git diff {branch}..{remote}/{branch}".format(
                    branch=args.branch.strip(), remote=args.remote.strip()
                )), cwd=git_dir
            )))
        ))
